@@ -4,9 +4,9 @@ Main interface for secretsmanager service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_secretsmanager.type_defs import RotationRulesTypeTypeDef
+    from mypy_boto3_secretsmanager.type_defs import ReplicationStatusTypeTypeDef
 
-    data: RotationRulesTypeTypeDef = {...}
+    data: ReplicationStatusTypeTypeDef = {...}
     ```
 """
 import sys
@@ -24,6 +24,7 @@ else:
 
 
 __all__ = (
+    "ReplicationStatusTypeTypeDef",
     "RotationRulesTypeTypeDef",
     "SecretListEntryTypeDef",
     "SecretVersionsListEntryTypeDef",
@@ -43,13 +44,29 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PutResourcePolicyResponseTypeDef",
     "PutSecretValueResponseTypeDef",
+    "RemoveRegionsFromReplicationResponseTypeDef",
+    "ReplicaRegionTypeTypeDef",
+    "ReplicateSecretToRegionsResponseTypeDef",
     "RestoreSecretResponseTypeDef",
     "RotateSecretResponseTypeDef",
+    "StopReplicationToReplicaResponseTypeDef",
     "UpdateSecretResponseTypeDef",
     "UpdateSecretVersionStageResponseTypeDef",
     "ValidateResourcePolicyResponseTypeDef",
 )
 
+ReplicationStatusTypeTypeDef = TypedDict(
+    "ReplicationStatusTypeTypeDef",
+    {
+        "Region": str,
+        "KmsKeyId": str,
+        "Status": Literal["InSync", "Failed", "InProgress"],
+        "StatusMessage": str,
+        "LastAccessedDate": datetime,
+    },
+    total=False,
+)
+
 RotationRulesTypeTypeDef = TypedDict(
     "RotationRulesTypeTypeDef", {"AutomaticallyAfterDays": int}, total=False
 )
@@ -72,6 +89,7 @@ SecretListEntryTypeDef = TypedDict(
         "SecretVersionsToStages": Dict[str, List[str]],
         "OwningService": str,
         "CreatedDate": datetime,
+        "PrimaryRegion": str,
     },
     total=False,
 )
@@ -98,7 +116,14 @@ CancelRotateSecretResponseTypeDef = TypedDict(
 )
 
 CreateSecretResponseTypeDef = TypedDict(
-    "CreateSecretResponseTypeDef", {"ARN": str, "Name": str, "VersionId": str}, total=False
+    "CreateSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
+    },
+    total=False,
 )
 
 DeleteResourcePolicyResponseTypeDef = TypedDict(
@@ -127,13 +152,18 @@ DescribeSecretResponseTypeDef = TypedDict(
         "VersionIdsToStages": Dict[str, List[str]],
         "OwningService": str,
         "CreatedDate": datetime,
+        "PrimaryRegion": str,
+        "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
     },
     total=False,
 )
 
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
-    {"Key": Literal["description", "name", "tag-key", "tag-value", "all"], "Values": List[str]},
+    {
+        "Key": Literal["description", "name", "tag-key", "tag-value", "primary-region", "all"],
+        "Values": List[str],
+    },
     total=False,
 )
 
@@ -187,6 +217,22 @@ PutSecretValueResponseTypeDef = TypedDict(
     total=False,
 )
 
+RemoveRegionsFromReplicationResponseTypeDef = TypedDict(
+    "RemoveRegionsFromReplicationResponseTypeDef",
+    {"ARN": str, "ReplicationStatus": List["ReplicationStatusTypeTypeDef"]},
+    total=False,
+)
+
+ReplicaRegionTypeTypeDef = TypedDict(
+    "ReplicaRegionTypeTypeDef", {"Region": str, "KmsKeyId": str}, total=False
+)
+
+ReplicateSecretToRegionsResponseTypeDef = TypedDict(
+    "ReplicateSecretToRegionsResponseTypeDef",
+    {"ARN": str, "ReplicationStatus": List["ReplicationStatusTypeTypeDef"]},
+    total=False,
+)
+
 RestoreSecretResponseTypeDef = TypedDict(
     "RestoreSecretResponseTypeDef", {"ARN": str, "Name": str}, total=False
 )
@@ -195,6 +241,10 @@ RotateSecretResponseTypeDef = TypedDict(
     "RotateSecretResponseTypeDef", {"ARN": str, "Name": str, "VersionId": str}, total=False
 )
 
+StopReplicationToReplicaResponseTypeDef = TypedDict(
+    "StopReplicationToReplicaResponseTypeDef", {"ARN": str}, total=False
+)
+
 UpdateSecretResponseTypeDef = TypedDict(
     "UpdateSecretResponseTypeDef", {"ARN": str, "Name": str, "VersionId": str}, total=False
 )
